from django.contrib import admin

from .forms import FieldSanitizerAdminForm
from .models import FieldSanitizer


class FieldSanitizerAdmin(admin.ModelAdmin):
    list_display = ('content_type', 'app_name', 'model_name', 'field_name', )
    form = FieldSanitizerAdminForm

admin.site.register(FieldSanitizer, FieldSanitizerAdmin)



"""
Management utility to clean a specific Model that is registered with a
FieldSanitizer.
"""
from django.core.management.base import CommandError, LabelCommand
from janitor.models import FieldSanitizer, _clean_class_objects


class Command(LabelCommand):

    help = "Cleans fields for a specified Model"
    args = "[appname.modelname]"
    label = 'application name.model name'

    can_import_settings = False

    def __init__(self, *args, **kwargs):
        super(Command, self).__init__(*args, **kwargs)

        # BaseCommand doesn't have stdout included in Django < 1.2
        # So, let's add it in if it's not already there.
        if not hasattr(self, 'stdout'):
            from sys import stdout
            self.stdout = stdout

    def handle_label(self, label, **options):
        try:
            app_label, model = label.lower().split('.')
        except ValueError:
            raise CommandError(
                "Invalid app_label.model_name: {0}".format(label)
            )

        self.stdout.write("\nCleaning {0}.{1}\n".format(app_label, model))

        qs = FieldSanitizer.objects.filter(
            content_type__app_label=app_label,
            content_type__model=model
        )
        try:
            assert qs.count() > 0
        except AssertionError:
            raise CommandError("It looks like there are no FieldSanitizers "
                "defined for {0}.{1}".format(app_label, model)
            )

        klass_list = [fs.content_type.model_class() for fs in qs]
        object_count = _clean_class_objects(klass_list)

        self.stdout.write("Cleaned {0} Objects\n".format(object_count))



# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'FieldSanitizer'
        db.create_table('janitor_fieldsanitizer', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('content_type', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['contenttypes.ContentType'])),
            ('field_name', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('tags', self.gf('django.db.models.fields.TextField')(default='a, abbr, acronym, blockquote, cite, code, dd, del, dfn, dl, dt, em, h1, h2, h3, h4, h5, h6, hr, img, ins, kbd, li, ol, p, pre, q, samp, strong, ul', blank=True)),
            ('attributes', self.gf('django.db.models.fields.TextField')(default='alt, class, href, id, src, title', blank=True)),
            ('styles', self.gf('django.db.models.fields.TextField')(blank=True)),
            ('strip', self.gf('django.db.models.fields.BooleanField')(default=False)),
            ('strip_comments', self.gf('django.db.models.fields.BooleanField')(default=True)),
        ))
        db.send_create_signal('janitor', ['FieldSanitizer'])

        # Adding unique constraint on 'FieldSanitizer', fields ['content_type', 'field_name']
        db.create_unique('janitor_fieldsanitizer', ['content_type_id', 'field_name'])


    def backwards(self, orm):
        # Removing unique constraint on 'FieldSanitizer', fields ['content_type', 'field_name']
        db.delete_unique('janitor_fieldsanitizer', ['content_type_id', 'field_name'])

        # Deleting model 'FieldSanitizer'
        db.delete_table('janitor_fieldsanitizer')


    models = {
        'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'janitor.fieldsanitizer': {
            'Meta': {'ordering': "['content_type', 'field_name']", 'unique_together': "(('content_type', 'field_name'),)", 'object_name': 'FieldSanitizer'},
            'attributes': ('django.db.models.fields.TextField', [], {'default': "'alt, class, href, id, src, title'", 'blank': 'True'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'field_name': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'strip': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'strip_comments': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'styles': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'tags': ('django.db.models.fields.TextField', [], {'default': "'a, abbr, acronym, blockquote, cite, code, dd, del, dfn, dl, dt, em, h1, h2, h3, h4, h5, h6, hr, img, ins, kbd, li, ol, p, pre, q, samp, strong, ul'", 'blank': 'True'})
        }
    }

    complete_apps = ['janitor']


"""Management utility to clean a specific Model that is registered with a
FieldSanitizer.
"""
from django.core.management.base import CommandError, LabelCommand
from janitor.models import _get_tags_used_in_content


class Command(LabelCommand):

    help = "Lists HTML elements used in a Model with a related FieldSanitizer"
    args = "[appname.modelname]"
    label = 'application name.model name'

    can_import_settings = False

    def __init__(self, *args, **kwargs):
        super(Command, self).__init__(*args, **kwargs)

        # BaseCommand doesn't have stdout included in Django < 1.2
        # So, let's add it in if it's not already there.
        if not hasattr(self, 'stdout'):
            from sys import stdout
            self.stdout = stdout

    def _tag_output(self, tag_list):
        p = "- {0}\n"
        return ''.join(p.format(t) for t in tag_list)

    def handle_label(self, label, **options):
        try:
            app_label, model = label.lower().split('.')
        except ValueError:
            raise CommandError(
                "Invalid app_label.model_name: {0}".format(label)
            )

        tag_list = _get_tags_used_in_content(app_label, model)
        self.stdout.write(
            "\nTags used in content:\n{0}\n".format(self._tag_output(tag_list))
        )



"""Test models."""
from django.db import models


class JanitorTestModel(models.Model):
    content = models.TextField()

    def __unicode__(self):
        return self.content

    class Meta:
        ordering = ['content']
        verbose_name = 'Janitor Test Model'
        verbose_name_plural = 'Janitor Test Models'
